@@ -29,6 +29,7 @@ var gAdvancedPane = {
     this.updateModeItems();
 //@line 68 "/builds/slave/mozilla-1.9.2-linux64-nightly/build/browser/components/preferences/advanced.js"
     this.updateOfflineApps();
+//@line 72 "/builds/slave/mozilla-1.9.2-linux64-nightly/build/browser/components/preferences/advanced.js"
   },
 
   /**
@@ -102,6 +103,35 @@ var gAdvancedPane = {
     return checkbox.checked ? (this._storedSpellCheck == 2 ? 2 : 1) : 0;
   },
 
+  /**
+   *
+   */
+  initSubmitCrashes: function ()
+  {
+    var checkbox = document.getElementById("submitCrashesBox");
+    try {
+      var cr = Components.classes["@mozilla.org/toolkit/crash-reporter;1"].
+               getService(Components.interfaces.nsICrashReporter_MOZILLA_1_9_2_BRANCH);
+      checkbox.checked = cr.submitReports;
+    } catch (e) {
+      checkbox.style.display = "none";
+    }
+  },
+
+  /**
+   *
+   */
+  updateSubmitCrashes: function ()
+  {
+    var checkbox = document.getElementById("submitCrashesBox");
+    try {
+      var cr = Components.classes["@mozilla.org/toolkit/crash-reporter;1"].
+               getService(Components.interfaces.nsICrashReporter);
+      cr.submitReports = checkbox.checked;
+    } catch (e) { }
+  },
+
+
   // NETWORK TAB
 
   /*
@@ -361,7 +391,7 @@ var gAdvancedPane = {
    *             iii 0/1/2   t         true   
    * 
    */
-//@line 402 "/builds/slave/mozilla-1.9.2-linux64-nightly/build/browser/components/preferences/advanced.js"
+//@line 434 "/builds/slave/mozilla-1.9.2-linux64-nightly/build/browser/components/preferences/advanced.js"
   updateAppUpdateItems: function () 
   {
     var aus = 
@@ -458,7 +488,7 @@ var gAdvancedPane = {
                              .createInstance(Components.interfaces.nsIUpdatePrompt);
     prompter.showUpdateHistory(window);
   },
-//@line 499 "/builds/slave/mozilla-1.9.2-linux64-nightly/build/browser/components/preferences/advanced.js"
+//@line 531 "/builds/slave/mozilla-1.9.2-linux64-nightly/build/browser/components/preferences/advanced.js"
 
   /**
    * The Extensions checkbox and button are disabled only if the enable Addon
@@ -528,7 +558,7 @@ var gAdvancedPane = {
                                         "chrome://pippki/content/device_manager.xul",
                                         "", null);
   }
-//@line 569 "/builds/slave/mozilla-1.9.2-linux64-nightly/build/browser/components/preferences/advanced.js"
+//@line 601 "/builds/slave/mozilla-1.9.2-linux64-nightly/build/browser/components/preferences/advanced.js"
   ,
 
   // SYSTEM DEFAULTS
@@ -574,5 +604,5 @@ var gAdvancedPane = {
       psvc.alert(window, promptTitle, promptMessage);
     }
   }
-//@line 615 "/builds/slave/mozilla-1.9.2-linux64-nightly/build/browser/components/preferences/advanced.js"
+//@line 647 "/builds/slave/mozilla-1.9.2-linux64-nightly/build/browser/components/preferences/advanced.js"
 };
